/*
    Copyright (c) 2010, 2011 aizo ag, Zurich, Switzerland

    Author: Sergey 'Jin' Bostandzhyan <jin@dev.digitalstrom.org>

    This file is part of dS Assistant.

    dS-Assistant is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    dS-Assistant is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with digitalSTROM Server. If not, see <http://www.gnu.org/licenses/>.

    NOTE: all APIs, especially the JSON API, offered by this application
          are subject to change without further notice.
*/


#ifndef __CREATE_DATABASE_H__
#define __CREATE_DATABASE_H__

#define CREATE_DB_V1 "\
BEGIN TRANSACTION;\
CREATE TABLE \"tasks\" (\
\"task_id\" INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL DEFAULT (1),\
\"status\" INTEGER,\
\"queued\" DATE,\
\"started\" DATE,\
\"finished\" DATE,\
\"type\" INTEGER,\
\"parameters\" TEXT DEFAULT NULL\
);\
CREATE TABLE \"taskdata_test_transmission_quality\" (\
\"dsid\" CHAR(24),\
\"upstream\" INTEGER,\
\"downstream\" INTEGER,\
\"timestamp\" DATE,\
\"errorcode\" INTEGER,\
\"task_id\" INTEGER,\
FOREIGN KEY(\"task_id\") REFERENCES tasks(task_id)\
);\
CREATE TABLE \"dsa_config\" (\
\"key\" varchar(40) primary key NOT NULL,\
\"value\" varchar(255) NOT NULL\
);\
CREATE INDEX dsa_config_key ON dsa_config(key);\
INSERT INTO \"dsa_config\" VALUES('db_version', '1');\
CREATE TRIGGER \"transmission_quality_taskdata_cleanup\" \
BEFORE DELETE ON \"tasks\" \
FOR EACH ROW BEGIN \
DELETE FROM \"taskdata_test_transmission_quality\" WHERE \"task_id\" = OLD.task_id;\
END;\
COMMIT;"

#define CREATE_DB_V2 "\
BEGIN TRANSACTION;\
CREATE TABLE \"taskdata_test_device_presence\" (\
\"dsid\" CHAR(24),\
\"dsmdsid\" CHAR(24),\
\"deviceid\" INTEGER,\
\"resultcode\" INTEGER,\
\"timestamp\" DATE,\
\"task_id\" INTEGER,\
FOREIGN KEY(\"task_id\") REFERENCES tasks(task_id)\
);\
CREATE TABLE \"taskdata_device_statistic\" (\
\"dsid\" CHAR(24),\
\"dsmdsid\" CHAR(24),\
\"deviceid\" INTEGER,\
\"value\" INTEGER,\
\"timestamp\" DATE,\
\"errorcode\" INTEGER,\
\"stat_id\" INTEGER,\
\"task_id\" INTEGER,\
FOREIGN KEY(\"stat_id\") REFERENCES dsa_statistic(stat_id)\
FOREIGN KEY(\"task_id\") REFERENCES tasks(task_id)\
);\
CREATE TABLE \"taskdata_meter_statistic\" (\
\"dsmdsid\" CHAR(24),\
\"value\" INTEGER,\
\"timestamp\" DATE,\
\"errorcode\" INTEGER,\
\"stat_id\" INTEGER,\
\"task_id\" INTEGER,\
FOREIGN KEY(\"stat_id\") REFERENCES dsa_statistic(stat_id)\
FOREIGN KEY(\"task_id\") REFERENCES tasks(task_id)\
);\
CREATE TABLE \"taskdata_upstream_metric\" (\
\"dsid\" CHAR(24),\
\"dsmdsid\" CHAR(24),\
\"deviceid\" INTEGER,\
\"quality\" INTEGER,\
\"polarity\" INTEGER,\
\"crosstalk\" INTEGER,\
\"packettype\" INTEGER,\
\"timestamp\" DATE\
);\
ALTER TABLE \"tasks\" ADD \"parent_task_id\" INTEGER;\
CREATE TABLE \"dsms\" (\
\"dsid\" CHAR(24) PRIMARY KEY NOT NULL,\
\"hwversion\" INTEGER,\
\"armswversion\" INTEGER,\
\"dspswversion\" INTEGER,\
\"apiversion\" INTEGER,\
\"name\" CHAR(21),\
\"present\" INTEGER,\
\"apartmentid\" INTEGER,\
\"configid\" INTEGER,\
\"countdevices\" INTEGER,\
\"countactivedevices\" INTEGER,\
\"countinactivedevices\" INTEGER\
);\
CREATE TABLE \"dsm_zones\" (\
\"dsid\" CHAR(24),\
\"index\" INTEGER,\
\"zoneid\" INTEGER,\
FOREIGN KEY(\"dsid\") REFERENCES dsms(dsid)\
);\
CREATE TRIGGER \"dsm_zonedata_cleanup\" \
BEFORE DELETE ON \"dsms\" \
FOR EACH ROW BEGIN \
DELETE FROM \"dsm_zones\" WHERE \"dsid\" = OLD.dsid;\
END;\
CREATE TABLE \"devices\" (\
\"key\" CHAR(54) PRIMARY KEY NOT NULL,\
\"dsid\" CHAR(24),\
\"dsmdsid\" CHAR(24),\
\"deviceid\" INTEGER,\
\"productid\" INTEGER,\
\"functionid\" INTEGER,\
\"version\" INTEGER,\
\"zoneid\" INTEGER,\
\"state\" INTEGER,\
\"locked\" INTEGER,\
\"outputmode\" INTEGER,\
\"name\" CHAR(21),\
\"serialnumber\" INTEGER\
);\
UPDATE \"dsa_config\" SET value=\'2\' WHERE key=\'db_version\';\
INSERT INTO \"dsa_config\" VALUES('MeterPingMode', '3');\
INSERT INTO \"dsa_config\" VALUES('MeterTemperatureWarning', '90');\
INSERT INTO \"dsa_config\" VALUES('MeterTemperatureError', '150');\
COMMIT;\
"
#define CREATE_DB_V3 "\
BEGIN TRANSACTION;\
ALTER TABLE \"devices\" ADD \"ltmode\" INTEGER;\
UPDATE \"dsa_config\" SET value=\'3\' WHERE key=\'db_version\';\
COMMIT;\
"
#define CREATE_DB_V4 "\
BEGIN TRANSACTION;\
CREATE TABLE \"dsm_state\" (\
\"dsid\" CHAR(24) PRIMARY KEY NOT NULL,\
\"hardware\" INTEGER,\
\"communicationdsp\" INTEGER,\
\"temperature\" INTEGER,\
\"configuration\" INTEGER,\
\"ds485bus\" INTEGER,\
\"powerline\" INTEGER,\
FOREIGN KEY(\"dsid\") REFERENCES dsms(dsid)\
);\
UPDATE \"dsa_config\" SET value=\'4\' WHERE key=\'db_version\';\
COMMIT;\
"

#include "hwstats.sql"

#endif//__CREATE_DATABASE_H__
